@@ -73,6 +73,11 @@ int main() {
   ensure_js("a[1] == 1");
   ensure_js("a[2] == 3");
   ensure_js_not("a[2] == 2");
+  vector<int> vec2_from_iter;
+  for (val&& v : val::global("a")) {
+    vec2_from_iter.push_back(v.as<int>());
+  }
+  ensure(vec2 == vec2_from_iter);
 
   test("template<typename Iter> val array(Iter begin, Iter end)");
   val::global().set("a", val::array(vec1.begin(), vec1.end()));
@@ -159,8 +164,15 @@ int main() {
 
   test("bool isNull()");
   EM_ASM(
-    a = null;
-    b = false;
+    globalThis.a = null;
+    globalThis.b = false;
+    globalThis.c = null;
+    globalThis.d = null;
+    globalThis.e = null;
+    globalThis.f = null;
+    globalThis.g = null;
+    globalThis.h = null;
+    globalThis.i = null;
   );
   ensure(val::global("a").isNull());
   ensure_not(val::global("b").isNull());
@@ -225,6 +237,17 @@ int main() {
   ensure_not(val::global("c").isArray());
   ensure_not(val::global("d").isArray());
 
+  test("val& operator=(val&& v)");
+  val source(val::object());
+  val target(val::object());
+  source.set("val", 1);
+  target = std::move(source);
+  ensure(target["val"].as<int>() == 1);
+  // move and assign to itself
+  target.set("val", 2);
+  target = std::move(target);
+  ensure(target["val"].as<int>() == 2);
+
   test("bool equals(const val& v)");
   EM_ASM(
     a = 1;
@@ -368,7 +391,7 @@ int main() {
 
   test("template<typename... Args> val new_(Args&&... args)");
   EM_ASM(
-    A = function() {
+    globalThis.A = function() {
       this.value = 2;
     }
   );
@@ -376,7 +399,7 @@ int main() {
   ensure_js("a instanceof A");
   ensure_js("a.value == 2");
   EM_ASM(
-    A = function(arg1, arg2) {
+    globalThis.A = function(arg1, arg2) {
       this.arg1 = arg1;
       this.arg2 = arg2;
     }
@@ -401,7 +424,7 @@ int main() {
   ensure_js("a == 2");
   val::global().set("a", val(3));
   ensure_js("a == 3");
-  val::global().set("a", NULL);
+  val::global().set("a", 0);
   ensure_js("a == 0");
   val::global().set("a", false);
   ensure_js("a == false");
@@ -425,10 +448,10 @@ int main() {
   ensure(val::global("f")().as<int>() == 2);
   ensure_not(val::global("f")().as<int>() == 3);
   EM_ASM(
-    f1 = function(arg1, arg2) {
+    globalThis.f1 = function(arg1, arg2) {
       return arg1;
     };
-    f2 = function(arg1, arg2) {
+    globalThis.f2 = function(arg1, arg2) {
       return arg2;
     };
   );
@@ -437,14 +460,14 @@ int main() {
 
   test("template<typename ReturnValue, typename... Args> ReturnValue call(const char* name, Args&&... args)");
   EM_ASM(
-    C = function() {
+    globalThis.C = function() {
       this.method = function() { return this; };
     };
     c = new C;
   );
   ensure(val::global("c").call<val>("method") == val::global("c"));
   EM_ASM(
-    C = function() {
+    globalThis.C = function() {
       this.method = function(arg) { return arg; };
     };
     c = new C;
@@ -520,8 +543,8 @@ int main() {
 
   test("bool instanceof(const val& v)");
   EM_ASM(
-    A = function() {};
-    B = function() {};
+    globalThis.A = function() {};
+    globalThis.B = function() {};
     a = new A;
   );
   ensure(val::global("a").instanceof(val::global("A")));
@@ -567,15 +590,11 @@ int main() {
 
   test("void throw_() const");
   EM_ASM(
-    test_val_throw_ = function(error)
-    {
-      try
-      {
+    globalThis.test_val_throw_ = function(error) {
+      try {
         Module.throw_js_error(error);
         return false;
-      }
-      catch(error_thrown)
-      {
+      } catch(error_thrown) {
         if (error_thrown != error)
           throw error_thrown;
       }
